@@ -41,11 +41,15 @@ from .backports import subprocess
 from .which import which
 
 
+__version__ = '0.7'
+
+
 __all__ = ['LanguageTool', 'Error', 'get_languages', 'correct', 'get_version',
            'get_directory', 'set_directory']
 
 JAR_NAMES = [
-    'languagetool-standalone*.jar',    # 2.1
+    'languagetool-server.jar',
+    'languagetool-standalone*.jar',  # 2.1
     'LanguageTool.jar',
     'LanguageTool.uno.jar'
 ]
